@@ -66,7 +66,7 @@ fi
 # set defaults, if nothing given
 [ "${KERNEL}" = "" ] && KERNEL=$(uname -r)
 [ "${LTS_KERNEL}" = "" ] && LTS_KERNEL="2.6.32-lts"
-[ "${RELEASENAME}" = "" ] && RELEASENAME="2k10-R8"
+[ "${RELEASENAME}" = "" ] && RELEASENAME="2k11-R1"
 [ "${IMAGENAME}" = "" ] && IMAGENAME="Archlinux-allinone-$(date +%Y.%m)"
 
 # generate temp directories
@@ -98,7 +98,7 @@ mv ${CORE}/tmp/*/arch/archboot.txt ${ALLINONE}/arch/
 if [ -d /var/lib/clamav -a -x /usr/bin/freshclam ]; then
     mkdir ${ALLINONE}/clamav
     rm -f /var/lib/clamav/*
-    freshclam
+    freshclam --user=root
     cp /var/lib/clamav/daily.cvd ${ALLINONE}/clamav/
     cp /var/lib/clamav/main.cvd ${ALLINONE}/clamav/
     cp /var/lib/clamav/bytecode.cvd ${ALLINONE}/clamav/
