@@ -4,7 +4,7 @@ SVNSETUP="svn://svn.archlinux.org/packages/"
 BASE=""
 DEVEL=""
 SUPPORT=""
-SUPPORT_ADDITION="gnu-netcat ntfs-3g fuse dhclient nouveau-drm-lts nouveau-firmware v86d btrfs-progs-unstable nilfs-utils"
+SUPPORT_ADDITION="gnu-netcat dosfstools ntfs-3g fuse dhclient nouveau-drm-lts nouveau-firmware v86d"
 # generate base
 for i in $(pacman -Sg base | sed -e "s/base//g"); do 
 	BASE="$BASE $(echo $i)"
